==> nemiver_0.9.5.orig.tar.xz: nemiver-0.9.5/src/uicommon/nmv-locate-file-dialog.h <==
//Author: Jonathon Jongsma
/*
 *This file is part of the Nemiver project
 *
 *Nemiver is free software; you can redistribute
 *it and/or modify it under the terms of
 *the GNU General Public License as published by the
 *Free Software Foundation; either version 2,
 *or (at your option) any later version.
 *
 *Nemiver is distributed in the hope that it will
 *be useful, but WITHOUT ANY WARRANTY;
 *without even the implied warranty of
 *MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *See the GNU General Public License for more details.
 *
 *You should have received a copy of the
 *GNU General Public License along with Nemiver;
 *see the file COPYING.
 *If not, write to the Free Software Foundation,
 *Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 *See COPYRIGHT file copyright information.
 */
#ifndef __NMV_LOCATE_FILE_DIALOG_H__
#define __NMV_LOCATE_FILE_DIALOG_H__

#include "common/nmv-safe-ptr-utils.h"
#include "nmv-dialog.h"

NEMIVER_BEGIN_NAMESPACE (nemiver)

namespace common {
class UString;
}

using nemiver::common::UString;
using nemiver::common::SafePtr;

class LocateFileDialog : public Dialog {
    class Priv;
    SafePtr<Priv> m_priv;
public:
    LocateFileDialog (const UString &a_resource_root_path,
                      const UString &a_file);
    virtual ~LocateFileDialog ();

    UString file_location () const;
    void file_location (const UString &a_location);
};//end class nemiver

NEMIVER_END_NAMESPACE (nemiver)

#endif //__NMV_LOCATE_FILE_DIALOG_H__

==> nemiver_0.9.6.orig.tar.xz: nemiver-0.9.6/src/uicommon/nmv-locate-file-dialog.h <==
//Author: Jonathon Jongsma
/*
 *This file is part of the Nemiver project
 *
 *Nemiver is free software; you can redistribute
 *it and/or modify it under the terms of
 *the GNU General Public License as published by the
 *Free Software Foundation; either version 2,
 *or (at your option) any later version.
 *
 *Nemiver is distributed in the hope that it will
 *be useful, but WITHOUT ANY WARRANTY;
 *without even the implied warranty of
 *MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *See the GNU General Public License for more details.
 *
 *You should have received a copy of the
 *GNU General Public License along with Nemiver;
 *see the file COPYING.
 *If not, write to the Free Software Foundation,
 *Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 *See COPYRIGHT file copyright information.
 */
#ifndef __NMV_LOCATE_FILE_DIALOG_H__
#define __NMV_LOCATE_FILE_DIALOG_H__

#include "common/nmv-safe-ptr-utils.h"
#include "nmv-dialog.h"

NEMIVER_BEGIN_NAMESPACE (nemiver)

namespace common {
class UString;
}

using nemiver::common::UString;
using nemiver::common::SafePtr;

class LocateFileDialog : public Dialog {
    class Priv;
    SafePtr<Priv> m_priv;
public:
    LocateFileDialog (const UString &a_resource_root_path,
                      const UString &a_file,
                      Gtk::Window &a_parent);
    virtual ~LocateFileDialog ();

    UString file_location () const;
    void file_location (const UString &a_location);
};//end class nemiver

NEMIVER_END_NAMESPACE (nemiver)

#endif //__NMV_LOCATE_FILE_DIALOG_H__
